<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link  https://wp1.co
 * @since 1.0.0
 *
 * @package    Product_Brands_For_Woocommerce
 * @subpackage Product_Brands_For_Woocommerce/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Product_Brands_For_Woocommerce
 * @subpackage Product_Brands_For_Woocommerce/admin
 */
class Product_Brands_For_Woocommerce_Admin {


	/**
	 * The ID of this plugin.
	 *
	 * @since  1.0.0
	 * @var    string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since  1.0.0
	 * @var    string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 1.0.0
	 * @param string $plugin_name The name of this plugin.
	 * @param string $version     The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since 1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Product_Brands_For_Woocommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Product_Brands_For_Woocommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/product-brands-for-woocommerce-admin.css', array(), $this->version, 'all');

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since 1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Product_Brands_For_Woocommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Product_Brands_For_Woocommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/product-brands-for-woocommerce-admin.js', array( 'jquery' ), $this->version, false);

		wp_enqueue_media();
	}
	
	

	public function product_brands_for_woocommerce_add_new_image_sizes() {
		add_image_size('product_brand', 450, 300, true);
		add_image_size('product_brand_thumb', 90, 60, true);
	}


	public function product_brands_for_woocommerce_product_taxonomies() {
		$labels = array(
		'name'                          => _x('Brands', 'Brands', 'product-brands-for-woocommerce'),
		'singular_name'                 => _x('Brand', 'Brand', 'product-brands-for-woocommerce'),
		'search_items'                  => __('Search Brands', 'product-brands-for-woocommerce'),
		'all_items'                     => __('All Brands', 'product-brands-for-woocommerce'),
		'parent_item'                   => __('Parent Brand', 'product-brands-for-woocommerce'),
		'parent_item_colon'             => __('Parent Brand:', 'product-brands-for-woocommerce'),
		'edit_item'                     => __('Edit Brand', 'product-brands-for-woocommerce'),
		'update_item'                   => __('Update Brand', 'product-brands-for-woocommerce'),
		'add_new_item'                  => __('Add New Brand', 'product-brands-for-woocommerce'),
		'new_item_name'                  => __('New Brand Name', 'product-brands-for-woocommerce'),
		'separate_items_with_commas'     => __('Separate brands with commas', 'product-brands-for-woocommerce'),
		'add_or_remove_items'            => __('Add or remove brands', 'product-brands-for-woocommerce'),
		'choose_from_most_used'          => __('Choose from the most used brands', 'product-brands-for-woocommerce'),
		'not_found'                      => __('No brands found.', 'product-brands-for-woocommerce'),
		'menu_name'                      => __('Brands', 'product-brands-for-woocommerce'),
		);
		$args = array(
		'hierarchical'         => false,
		'labels'            => $labels,
		'show_ui'           => true,
		'show_in_quick_edit' => false,
		'show_admin_column' => true,
		'query_var'         => true,
		'public' => true,
		'rewrite'           => array( 'slug' => 'product-brand' ),
		);
		register_taxonomy('product-brand', array( 'product' ), $args);
	}


	public function product_brands_for_woocommerce_add_brand_image( $taxonomy ) {
		?>
		<div class="form-field term-group">
		  <label for="brand-image-id"><?php esc_html_e('Image', 'product-brands-for-woocommerce'); ?></label>
		  <input type="hidden" id="brand-image-id" name="brand-image-id" class="custom_media_url" value="">
		  <div id="brand-image-wrapper"></div>
		  <p>
			<input type="button" class="button button-secondary ct_tax_media_button" id="ct_tax_media_button" name="ct_tax_media_button" value="<?php esc_html_e('Add Image', 'product-brands-for-woocommerce'); ?>" />
			<input type="button" class="button button-secondary ct_tax_media_remove" id="ct_tax_media_remove" name="ct_tax_media_remove" value="<?php esc_html_e('Remove Image', 'product-brands-for-woocommerce'); ?>" />
			</p>
			<p>Uplaod image in (450 X 300) OR (600 X 400) OR (900 X 600) pixel size.</p>
		</div>
		<?php
	}



	public function product_brands_for_woocommerce_save_brand_image( $term_id, $tt_id ) {
		$brand_image_nonce = wp_create_nonce( 'brand-image-nonce' );
		if (isset($_POST['brand-image-id']) && '' !== $_POST['brand-image-id'] && wp_verify_nonce( $brand_image_nonce, 'brand-image-nonce' ) ) {
			$image = intval( $_POST['brand-image-id'] );
			add_term_meta($term_id, 'brand-image-id', $image, true);
		}
	}


	
	public function product_brands_for_woocommerce_update_brand_image( $term, $taxonomy ) {
		?>
		<tr class="form-field term-group-wrap">
		  <th scope="row">
			<label for="brand-image-id"><?php esc_html_e('Image', 'product-brands-for-woocommerce'); ?></label>
		  </th>
		  <td>
		<?php $image_id = get_term_meta($term->term_id, 'brand-image-id', true); ?>
			<input type="hidden" id="brand-image-id" name="brand-image-id" value="<?php echo intval($image_id); ?>">
			<div id="brand-image-wrapper">
		<?php if ($image_id ) { ?>
			<?php echo wp_get_attachment_image($image_id, 'product_brand_thumb'); ?>
		<?php } ?>
			</div>
			<p>
			  <input type="button" class="button button-secondary ct_tax_media_button" id="ct_tax_media_button" name="ct_tax_media_button" value="<?php esc_html_e('Add Image', 'product-brands-for-woocommerce'); ?>" />
			  <input type="button" class="button button-secondary ct_tax_media_remove" id="ct_tax_media_remove" name="ct_tax_media_remove" value="<?php esc_html_e('Remove Image', 'product-brands-for-woocommerce'); ?>" />
			</p>
			<p class="description">Uplaod image in (450 X 300) OR (600 X 400) OR (900 X 600) pixel size.</p>
		  </td>
		</tr>
		<?php
	}


	public function product_brands_for_woocommerce_updated_brand_image( $term_id, $tt_id ) {
		$brand_image_nonce = wp_create_nonce( 'brand-image-nonce' );
		if ( isset($_POST['brand-image-id']) && wp_verify_nonce( $brand_image_nonce, 'brand-image-nonce' ) ) {
			$image = intval( $_POST['brand-image-id'] );
			update_term_meta($term_id, 'brand-image-id', $image);
		}
	}


	public function product_brands_for_woocommerce_add_brand_columns( $columns ) {
		$columns['brandimage'] = 'Image';
		return $columns;
	}

	
	public function product_brands_for_woocommerce_before_order_itemmeta( $item_id, $item, $_product ) {
		if ( isset($_product) && null !== $_product->get_id() ) {
			$prd_id = ( $_product->get_parent_id() > 0 ) ? $_product->get_parent_id() : $_product->get_id();
			$term_obj_list = ( get_the_terms($prd_id, 'product-brand') ) ? get_the_terms($prd_id, 'product-brand') : array();
			$term_links = array();
			if ( isset($term_obj_list[0]->name) && !empty($term_obj_list[0]->name) ) {
				echo '<div class="wc-order-item-sku"><strong>' . esc_attr__('Brand:', 'product-brands-for-woocommerce') . '</strong> ' . esc_attr( $term_obj_list[0]->name ) . '</div>';
			}
		}
	}


	public function product_brands_for_woocommerce_add_brand_column_content( $content, $column_name, $term_id) {
		$image_id = get_term_meta($term_id, 'brand-image-id', true);
		switch ($column_name) {
			case 'brandimage':
				$content = wp_get_attachment_image($image_id, 'product_brand_thumb');
				break;
			default:
				break;
		}
		return $content;
	}


	public function product_brands_for_woocommerce_bulk_edit_add( $column_name, $post_type ) {
		global $post;
		switch ( $column_name ) :
			case 'taxonomy-product-brand':
				wp_nonce_field( 'pbfwc_bulk_edit_nonce', 'pbfwc_bulk_edit' );
				break;
		endswitch;
	}

	
	public function product_brands_for_woocommerce_quick_edit_add( $column_name, $post_type ) {
		global $post;
		switch ( $column_name ) :
			case 'taxonomy-product-brand': 
				wp_nonce_field( 'pbfwc_q_edit_nonce', 'pbfwc_quick_edit' );
				?>
				<fieldset class="inline-edit-col-right inline-edit-product-brands">
					<div class="inline-edit-col">
						<br />
						<span class="title inline-edit-product-brands-label">Product Brand</span>
						<ul class="cat-checklist product-brand-checklist">
							<?php
							$all_tags = get_terms(array('taxonomy' => 'product-brand', 'hide_empty' => 0)); 
							$all_tags_of_post = get_the_terms($post->ID, 'product-brand'); 
							$ids = array();
							if ($all_tags_of_post ) {
								foreach ($all_tags_of_post as $tag ) {
									$ids[] = $tag->term_id;
								}
							}
							foreach ( $all_tags as $tag ) {
								$checked = '';
								if (in_array($tag->term_id, $ids) ) {
									$checked = " checked='checked'";
								}
								$id = 'product-brand-' . $tag->term_id;
								echo '<li id="' . esc_attr( $id ) . '">';
								echo '<label class="selectit"><input type="checkbox" name="product_brand[]" id="in-' . esc_attr( $id ) . '" ' . esc_attr( $checked ) . ' value="' . esc_attr( $tag->slug ) . '" data-text="' . esc_attr( $tag->name ) . '" /> ' . esc_attr( $tag->name ) . '</label>';
								echo '</li>';
							}
							?>
						</ul>					
					</div>
				</fieldset>
				<?php
				break;
		endswitch;
	}


	public function product_brands_for_woocommerce_quick_edit_save( $post_id ) {

		if ( isset($_POST['pbfwc_quick_edit']) && current_user_can( 'edit_post', $post_id ) && wp_verify_nonce( sanitize_key($_POST['pbfwc_quick_edit']), 'pbfwc_q_edit_nonce' ) && isset( $_POST['product_brand'] ) ) {
			$product_brands = array_map( 'sanitize_text_field', wp_unslash( $_POST['product_brand'] ) );
			wp_set_post_terms( $post_id, $product_brands, 'product-brand' );
		}
		
	}


	public function product_brands_for_woocommerce_enqueue_quick_edit_script( $pagehook ) {

		// do nothing if we are not on the target pages
		if ( 'edit.php' != $pagehook ) {
			return;
		}

		wp_enqueue_script( 'populatequickedit', PRODUCT_BRANDS_FOR_WOOCOMMERCE_PLUGIN_URL . '/admin/js/product-brand-populate.js', array( 'jquery' ), $this->version, false);
	
	}


	public function product_brands_for_woocommerce_bulk_edit_save( $product ) {
		$post_id = $product->get_id();
		if ( isset( $_REQUEST['product_brand'] ) ) {
			$product_brands = array_map( 'sanitize_text_field', wp_unslash( $_REQUEST['product_brand'] ) );
			wp_set_post_terms( $post_id, $product_brands, 'product-brand' );
		}
	}


	public function product_brands_for_woocommerce_regenerate_permalinks_after_product_update() {
		flush_rewrite_rules(true);
	}

	
	public function product_brands_for_woocommerce_plugin_action_links( $links ) {
		$action_links = array(
			'settings' => '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=product_brands_for_woocommerce' ) . '" aria-label="' . esc_attr__( 'Product Brands for WooCommerce Settings', 'product-brands-for-woocommerce' ) . '">' . esc_html__( 'Settings', 'product-brands-for-woocommerce' ) . '</a>',
		);
		return array_merge( $action_links, $links );
	}

}
