<?php


add_action('admin_menu', 'product_brands_for_woocommerce_metabox_product_edit_screen');
function product_brands_for_woocommerce_metabox_product_edit_screen() {
	$id = 'tagsdiv-product-brand'; // it should be unique
	$heading = 'Brands'; // meta box heading
	$callback = 'product_brands_for_woocommerce_metabox_content_callback'; // the name of the callback function
	$post_type = 'product';
	$position = 'side';
	$pri = 'default'; // priority, 'default' is good for us
	add_meta_box($id, $heading, $callback, $post_type, $position, $pri);
}
 
function product_brands_for_woocommerce_metabox_content_callback( $post) {
	$all_tags = get_terms(array('taxonomy' => 'product-brand', 'hide_empty' => 0)); 
	$all_tags_of_post = get_the_terms($post->ID, 'product-brand');  

	$ids = array();
	if ($all_tags_of_post ) {
		foreach ($all_tags_of_post as $tag ) {
			$ids[] = $tag->term_id;
		}
	}
	echo '<div id="taxonomy-brand-metabox" class="categorydiv">';
	echo '<input type="hidden" name="tax_input[product-brand][]" value="0" />';
	echo '<ul>';
	foreach ( $all_tags as $tag ) {
		$checked = '';
		if (in_array($tag->term_id, $ids) ) {
			$checked = " checked='checked'";
		}
		$id = 'product-brand-' . $tag->term_id;
		echo '<li id="' . esc_attr( $id ) . '">';
		echo '<label><input type="checkbox" name="tax_input[product-brand][]" id="in-' . esc_attr( $id ) . '" ' . esc_attr( $checked ) . ' value="' . esc_attr( $tag->slug ) . '" /> ' . esc_attr( $tag->name ) . '</label><br />';
		echo '</li>';
	}
	echo '</ul></div>'; // end HTML
}


add_shortcode('product_brands', 'product_brands_for_woocommerce_shortcode_content');
function product_brands_for_woocommerce_shortcode_content( $atts ) {
	$a = shortcode_atts(
		array(
		'col' => 4,
		'hide_empty' => 0,
		'show_name' => 'false'
		), $atts 
	);

	$brand_listing = product_brands_for_woocommerce_get_product_listing($a['col'], $a['hide_empty'], $a['show_name']);
	return $brand_listing;
}


function product_brands_for_woocommerce_get_product_listing( $col = 4, $hide_empty = 0, $show_name = 'false' ) {
	$brand_listing = '<div class="woocommerce columns-' . $col . '"><ul class="products product-brands columns-' . $col . '">';
	$all_brands = get_terms(array('taxonomy' => 'product-brand', 'hide_empty' => $hide_empty)); 

	$first_class = 'first';
	$n = 0;
	foreach ( $all_brands as $brand ) {
		$n++;
		$brand_listing .= '<li class="product type-product ' . ( ( 0 == $n%$col ) ? 'last' : '' ) . ' ' . $first_class . ' has-post-thumbnail">';
		$image_id = get_term_meta($brand->term_id, 'brand-image-id', true);
		
		$brand_title_str = ( 'false' == $show_name ) ? '' : '<h2 class="woocommerce-loop-product__title">' . $brand->name . '</h2>';
		$image = empty(wp_get_attachment_image($image_id, 'product_brand')) ? '<img src="' . PRODUCT_BRANDS_FOR_WOOCOMMERCE_PLUGIN_URL . '/public/images/logo-placeholder.png">' : wp_get_attachment_image($image_id, 'product_brand');
		$brand_listing .= '<a href="' . esc_url(get_term_link($brand)) . '"  title="' . $brand->name . '">' . $image . $brand_title_str . '</a>';
		$brand_listing .= '</li>';
		$first_class = ( 0 == $n%$col ) ? 'first' : '';
	}
	$brand_listing .= '</ul></div>';
	return $brand_listing;
}


add_shortcode('products_by_brand', 'products_by_brand_for_woocommerce_shortcode_content');
function products_by_brand_for_woocommerce_shortcode_content( $atts ) {
	$a = shortcode_atts(
		array(
		'col' => 4,
		'brand' => '',
		'limit' => 4,
		), $atts 
	);

	$products = get_posts(
		array(
		'numberposts'         => -1,
		'post_type'          => 'product',
		'product-brand'         => $a['brand'],
		'post_status'        => 'publish',
		) 
	);
	
	$prd_ids = array();
	foreach ( $products as $prd ) {
		$prd_ids[] = $prd->ID;
	}

	$product_listing = wp_kses_post( do_shortcode('[products limit="' . $a['limit'] . '" columns="' . $a['col'] . '" ids="' . implode(',', $prd_ids) . '"]') );
	
	return $product_listing;
}


add_shortcode('product_brands_carousel', 'product_brands_for_woocommerce_carousel_shortcode_content');
function product_brands_for_woocommerce_carousel_shortcode_content( $atts ) {
	$a = shortcode_atts(
		array(
		'col' => 4,
		'bullets' => 'false',
		'show_name' => 'false',
		'hide_empty' => 0
		), $atts 
	);
	$rand = rand(10, 99);

	$brand_listing = '';
	$all_brands = get_terms(array('taxonomy' => 'product-brand', 'hide_empty' => $a['hide_empty'])); 
	foreach ( $all_brands as $brand ) {
		$image_id = get_term_meta($brand->term_id, 'brand-image-id', true);
		$image = empty(wp_get_attachment_image($image_id, 'product_brand')) ? '<img src="' . PRODUCT_BRANDS_FOR_WOOCOMMERCE_PLUGIN_URL . '/public/images/logo-placeholder.png">' : wp_get_attachment_image($image_id, 'product_brand');
		$brand_title_str = ( 'false' == $a['show_name'] ) ? '' : '<p>' . $brand->name . '</p>';
		$brand_listing .= '<div><a href="' . esc_url(get_term_link($brand)) . '" title="' . $brand->name . '">' . $image . $brand_title_str . '</a></div>';
	}

	$carousel_html = '<div class="product-brand-carousel-wrapper" id="product-brand-carousel-' . $rand . '">' . $brand_listing . '</div>
	<script>
	jQuery( function(){
		jQuery("#product-brand-carousel-' . $rand . '").slick({
			slidesToShow: ' . $a['col'] . ',
			slidesToScroll: 1,
			dots: ' . $a['bullets'] . ',
			focusOnSelect: true,
			infinite: true,
			responsive: [
			  {
				breakpoint: 800,
				settings: {
				  slidesToShow: 3
				}
			  },
			  {
				breakpoint: 540,
				settings: {
				  slidesToShow: 2
				}
			  }
			]
		});
	});
	</script>';
	return $carousel_html;
}

//[pbfwc_brand_title]
add_shortcode( 'pbfwc_brand_title', 'product_brands_for_woocommerce_archive_title_shortcode' );
function product_brands_for_woocommerce_archive_title_shortcode( $atts ) {
	$title = is_tax() ? single_term_title() : '';
	return $title;
}


//[pbfwc_brand_image width=360 height=240]
add_shortcode( 'pbfwc_brand_image', 'product_brands_for_woocommerce_brand_image_shortcode' );
function product_brands_for_woocommerce_brand_image_shortcode( $atts ) {
	$a = shortcode_atts( array(
		'width' => '150',
		'height' => '100',
	), $atts );

	$image = '';
	$term_brand = get_term_by( 'slug' , get_query_var( 'term' ), get_query_var( 'taxonomy' ) );
	if ( isset($term_brand->taxonomy) && 'product-brand' == $term_brand->taxonomy ) {
		$image_id = get_term_meta($term_brand->term_id, 'brand-image-id', true);
		if ( !empty(wp_get_attachment_image($image_id, 'product_brand')) ) {
			$image =  wp_get_attachment_image($image_id, 'product_brand', '', array( 'class' => 'pbfwc-brand-image-thumb-' . $image_id )) ;
			$image .= '<style>.pbfwc-brand-image-thumb-' . $image_id . '{ width:' . $a['width'] . 'px !important; height:' . $a['height'] . 'px !important; }</style>';
		}
	}
	return $image;
}



//[products_of_brand_archive]
function product_brands_for_woocommerce_products_of_brand_archive_shortcode( $atts ) {
	$content = '';
	if ( !is_admin() && null !== get_queried_object() && isset(get_queried_object()->taxonomy) && 'product-brand' == get_queried_object()->taxonomy ) {
		if ( isset(get_queried_object()->term_id) && get_queried_object()->term_id > 0 ) {
			$show_albums = get_posts( array(
				'posts_per_page' => -1,
				'orderby'        => 'date',
				'post_type'      => 'product',
				'product-brand'  => get_queried_object()->slug,
				'post_status'    => 'publish'
			) );
			$ids = array();
			foreach ($show_albums as $alb) {
				$ids[] = $alb->ID;
			}
			$id = implode(',', $ids);
			$content = do_shortcode('[products limit="-1" ids="' . $id . '"]');
		}
	}
	return $content;
}
add_shortcode( 'products_of_brand_archive', 'product_brands_for_woocommerce_products_of_brand_archive_shortcode' );



//[pbfwc_brand_info]
add_shortcode( 'pbfwc_brand_info', 'product_brands_for_woocommerce_brand_name_on_product_shortcode' );
function product_brands_for_woocommerce_brand_name_on_product_shortcode( $atts ) {
	if ( is_product() ) {
		$brand_info = product_brands_for_woocommerce_get_brand_information();
		$brand_info = '<div style="clear:both;"></div><p>' . $brand_info . '</p><div style="clear:both;"></div>';
		return wp_kses_post( $brand_info );
	}
}



function product_brands_for_woocommerce_get_brand_information() {
	global $post;

	$brand_info = '';
	
	$hide_brand_name = get_option( 'product_brands_for_woocommerce_hide_brand_name_on_product_page', 'no' );
	$hide_brand_logo = get_option( 'product_brands_for_woocommerce_hide_brand_logo_on_product_page', 'no' );
	$hide_brand_desc = get_option( 'product_brands_for_woocommerce_hide_brand_desc_on_product_page', 'no' );

	
	$term_obj_list = ( get_the_terms($post->ID, 'product-brand') ) ? get_the_terms($post->ID, 'product-brand') : array();
	$term_links = array();
	if (count($term_obj_list) > 0 ) {
		$brand_info_count = 0;
		foreach ( $term_obj_list as $prd_brand ) {

			$image_id = get_term_meta($prd_brand->term_id, 'brand-image-id', true);

			$brand_name = '';
			if ( 'no' == $hide_brand_name ) {
				$brand_name = $prd_brand->name;
				$brand_info_count++;
			}

			$image = '';
			if ( 'no' == $hide_brand_logo ) {
				$image = empty(wp_get_attachment_image($image_id, 'product_brand')) ? '' : wp_get_attachment_image($image_id, 'product_brand');
				$brand_info_count++;
			}

			$brand_desc = '';
			if ( 'no' == $hide_brand_desc ) {
				$brand_desc = !empty($prd_brand->description) ? '<br><small>' . $prd_brand->description . '</small>' : '';
				$brand_info_count++;
			}

			$active_brand_link = get_option( 'product_brands_for_woocommerce_link_brand_to_brand_archive', 'yes' );

			if ( 'yes' !== $active_brand_link ) {
				$term_links[] =  $image . $brand_name . $brand_desc;
			} else {
				$term_links[] =  '<a href="' . get_term_link($prd_brand->slug, 'product-brand') . '">' . $image . $brand_name . '</a>' . $brand_desc;
			}

		}

		if ( $brand_info_count > 0 ) {
			$brand_info .= '<span class="posted_in product_brand_posted_in">';
			$brand_info .= esc_attr('Brand:', 'product-brands-for-woocommerce');
			$brand_info .= ' ';
			$brand_info .= implode(', ', $term_links);
			$brand_info .= '</span><div style="clear:both;"></div>';
		}
	}
		
	return $brand_info;
}




// Creating the widget 
class Product_Brands_Widget extends WP_Widget {
  
	public function __construct() {
		parent::__construct(
			// Base ID of your widget
			'product_brands_widget', 

			// Widget name will appear in UI
			__('Product Brands', 'product-brands-for-woocommerce'), 
			
			// Widget description
			array( 'description' => __( 'Display a list of product brands.', 'product-brands-for-woocommerce' ), ) 
		);
	}
	  
	// Creating widget front-end
	public function widget( $args, $instance ) {
		$title = apply_filters( 'widget_title', $instance['title'] );
		
		$widget_content = '';
		// before and after widget arguments are defined by themes
		$widget_content .= $args['before_widget'] ;
		if ( ! empty( $title ) ) {
			$widget_content .= $args['before_title'] . $title . $args['after_title'];
		}

		global $wp;
		$cur_url = home_url( $wp->request );
		if ( !empty( $_SERVER['QUERY_STRING'] ) ) {
			
			$brands_array = array();
			parse_str( sanitize_text_field($_SERVER['QUERY_STRING']), $brands_array );
			if ( isset($brands_array['product-brand']) ) {
				unset($brands_array['product-brand']);
			}
			$query_str = http_build_query($brands_array);

			$cur_url = empty($query_str) ? $cur_url . '?' : $cur_url . '?' . $query_str . '&';
		} else {
			$cur_url .= '?';
		}
		$all_brands = get_terms( array('taxonomy' => 'product-brand') ); 
		if ( $all_brands ) {
			$widget_content .= '<ul class="product-brands-listing">';
			foreach ( $all_brands as $brand ) {
				$widget_content .= '<li><a href="' . $cur_url . 'product-brand=' . $brand->slug . '">' . $brand->name . '</a></li>';
			}
			$widget_content .= '</ul>';
		}

		$widget_content .= $args['after_widget'];

		echo wp_kses_post( $widget_content );
	}
			  
	// Widget Backend 
	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		} else {
			$title = __( 'Brands', 'product-brands-for-woocommerce' );
		}
		// Widget admin form
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Title:', 'product-brands-for-woocommerce' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<?php 
	}
		  
	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		return $instance;
	}
	 
	// Class product_brands_widget ends here
} 

// Register and load the widget
function product_brands_load_widget() {
	register_widget( 'Product_Brands_Widget' );
}
add_action( 'widgets_init', 'product_brands_load_widget' );


