<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
class Product_Brands_For_Woocommerce_Settings {
	public static function init() {
		add_filter( 'woocommerce_settings_tabs_array', __CLASS__ . '::add_settings_tab', 50 );
		add_action( 'woocommerce_settings_tabs_product_brands_for_woocommerce', __CLASS__ . '::settings_tab' );
		add_action( 'woocommerce_update_options_product_brands_for_woocommerce', __CLASS__ . '::update_settings' );
	}

	public static function add_settings_tab( $settings_tabs ) {
		$settings_tabs['product_brands_for_woocommerce'] = __( 'Product Brands', 'product-brands-for-woocommerce' );
		return $settings_tabs;
	}

	public static function settings_tab() {
		woocommerce_admin_fields( self::get_settings() );
	}

	public static function update_settings() {
		woocommerce_update_options( self::get_settings() );
	}

	public static function get_settings() {

		$font_sizes = array();
		$font_range = range(12, 60);
		foreach ( $font_range as $font_size ) {
			if ( 0 == $font_size%2 ) {
				$font_sizes[$font_size] = $font_size . 'px';
			}
		}
		$settings = array(
			'section_title' => array(
				'name'     => __( 'Product Brands for WooCommerce Settings', 'product-brands-for-woocommerce' ),
				'type'     => 'title',
				'desc'     => 'Product Brands for WooCommerce Configuration and Settings.',
				'id'       => 'product_brands_for_woocommerce_section_title',
			),
			'disable_brand_on_product_page' => array(
				'name' => __( 'Disable Brand Info on Product Page', 'product-brands-for-woocommerce' ),
				'type' => 'checkbox',
				'desc' => __( '<em><small>Check this box to disable brand information on product page.</small></em>', 'product-brands-for-woocommerce' ),
				'desc_tip' => false,
				'id' => 'product_brands_for_woocommerce_disable_brand_on_product_page',
				'default' => 'no',
			),
			'link_brand_to_brand_archive' => array(
				'name' => __( 'Link Brand Name to Brand Archive', 'product-brands-for-woocommerce' ),
				'type' => 'checkbox',
				'desc' => __( '<em><small>Check this box to link brand name to brand archive on product page.</small></em>', 'product-brands-for-woocommerce' ),
				'desc_tip' => false,
				'id' => 'product_brands_for_woocommerce_link_brand_to_brand_archive',
				'default' => 'yes',
			),
			'hide_brand_name_on_product_page' => array(
				'name' => __( 'Hide Brand Name on Product Page', 'product-brands-for-woocommerce' ),
				'type' => 'checkbox',
				'desc' => __( '<em><small>Check this box to hide brand name on product page.</small></em>', 'product-brands-for-woocommerce' ),
				'desc_tip' => false,
				'id' => 'product_brands_for_woocommerce_hide_brand_name_on_product_page',
				'default' => 'no',
			),
			'hide_brand_logo_on_product_page' => array(
				'name' => __( 'Hide Brand Logo on Product Page', 'product-brands-for-woocommerce' ),
				'type' => 'checkbox',
				'desc' => __( '<em><small>Check this box to hide brand logo on product page.</small></em>', 'product-brands-for-woocommerce' ),
				'desc_tip' => false,
				'id' => 'product_brands_for_woocommerce_hide_brand_logo_on_product_page',
				'default' => 'no',
			),
			'hide_brand_desc_on_product_page' => array(
				'name' => __( 'Hide Brand Description on Product Page', 'product-brands-for-woocommerce' ),
				'type' => 'checkbox',
				'desc' => __( '<em><small>Check this box to hide brand description on product page.</small></em>', 'product-brands-for-woocommerce' ),
				'desc_tip' => false,
				'id' => 'product_brands_for_woocommerce_hide_brand_desc_on_product_page',
				'default' => 'no',
			),
			'nofollow_brand_archive_pages' => array(
				'name' => __( 'Add NOFOLLOW Meta on Brand Archive', 'product-brands-for-woocommerce' ),
				'type' => 'checkbox',
				'desc' => __( '<em><small>Check this box to add nofollow meta on brand archive pages.</small></em>', 'product-brands-for-woocommerce' ),
				'desc_tip' => false,
				'id' => 'product_brands_for_woocommerce_nofollow_brand_archive_pages',
				'default' => 'no',
			),
			'noindex_brand_archive_pages' => array(
				'name' => __( 'Add NOINDEX Meta on Brand Archive', 'product-brands-for-woocommerce' ),
				'type' => 'checkbox',
				'desc' => __( '<em><small>Check this box to add noindex meta on brand archive pages.</small></em>', 'product-brands-for-woocommerce' ),
				'desc_tip' => false,
				'id' => 'product_brands_for_woocommerce_noindex_brand_archive_pages',
				'default' => 'no',
			),
			'section_end_configuration' => array(
				'type' => 'sectionend',
				'id' => 'product_brands_for_woocommerce_section_end_configuration',
			), 
		);
		return apply_filters( 'wc_product_brands_for_woocommerce_settings', $settings );
	}

}
Product_Brands_For_Woocommerce_Settings::init();

