<?php


function product_brands_for_woocommerce_add_columns( $columns ) {
	$columns[ 'product_brand_taxonomy' ] = __( 'Product Brand', 'product-brands-for-woocommerce' );
	return $columns;
}
add_filter( 'woocommerce_product_export_column_names', 'product_brands_for_woocommerce_add_columns' );
add_filter( 'woocommerce_product_export_product_default_columns', 'product_brands_for_woocommerce_add_columns' );


/**
* MnM contents data column content.
*
* @param  mixed       $value
* @param  WC_Product  $product
* @return mixed       $value
*/
function product_brands_for_woocommerce_export_taxonomy( $value, $product ) {

	$terms = get_terms( array( 'object_ids' => $product->get_ID(), 'taxonomy' => 'product-brand' ) );

	if ( ! is_wp_error( $terms ) ) {

		$data = array();

		foreach ( (array) $terms as $term ) {
			$data[] = $term->term_id;
		}

		$value = json_encode( $data );

	}

	return $value;
}
add_filter( 'woocommerce_product_export_product_column_product_brand_taxonomy', 'product_brands_for_woocommerce_export_taxonomy', 10, 2 );


/**
 * Register the 'Custom Column' column in the importer.
 *
 * @param  array  $columns
 * @return array  $columns
 */
function product_brands_for_woocommerce_map_columns( $columns ) {
	$columns[ 'product_brand_taxonomy' ] = __( 'Product Brand', 'product-brands-for-woocommerce' );
	return $columns;
}
add_filter( 'woocommerce_csv_product_import_mapping_options', 'product_brands_for_woocommerce_map_columns' );


/**
 * Add automatic mapping support for custom columns.
 *
 * @param  array  $columns
 * @return array  $columns
 */
function product_brands_for_woocommerce_add_columns_to_mapping_screen( $columns ) {

	$columns[ __( 'Product Brand', 'product-brands-for-woocommerce' ) ] 	= 'product_brand_taxonomy';

	// Always add English mappings.
	$columns[ 'Product Brand' ]	= 'product_brand_taxonomy';

	return $columns;
}
add_filter( 'woocommerce_csv_product_import_mapping_default_columns', 'product_brands_for_woocommerce_add_columns_to_mapping_screen' );


/**
 * Decode data items and parse JSON IDs.
 *
 * @param  array                    $parsed_data
 * @param  WC_Product_CSV_Importer  $importer
 * @return array
 */
function product_brands_for_woocommerce_parse_taxonomy_json( $parsed_data, $importer ) {

	if ( ! empty( $parsed_data[ 'product_brand_taxonomy' ] ) ) {

		$data = json_decode( $parsed_data[ 'product_brand_taxonomy' ], true );

		unset( $parsed_data[ 'product_brand_taxonomy' ] );

		if ( is_array( $data ) ) {

			$parsed_data[ 'product_brand_taxonomy' ] = array();

			foreach ( $data as $term_id ) {
				$parsed_data[ 'product_brand_taxonomy' ][] = $term_id;
			}
		}
	}

	return $parsed_data;
}
add_filter( 'woocommerce_product_importer_parsed_data', 'product_brands_for_woocommerce_parse_taxonomy_json', 10, 2 );


/**
 * Set taxonomy.
 *
 * @param  array  $parsed_data
 * @return array
 */
function product_brands_for_woocommerce_set_taxonomy( $product, $data ) {

	if ( is_a( $product, 'WC_Product' ) ) {

		if ( ! empty( $data[ 'product_brand_taxonomy' ] ) ) {
			wp_set_object_terms( $product->get_id(), (array) $data[ 'product_brand_taxonomy' ], 'product-brand' );
		}

	}

	return $product;
}
add_filter( 'woocommerce_product_import_inserted_product_object', 'product_brands_for_woocommerce_set_taxonomy', 10, 2 );
