<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link  https://wp1.co
 * @since 1.0.0
 *
 * @package    Product_Brands_For_Woocommerce
 * @subpackage Product_Brands_For_Woocommerce/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Product_Brands_For_Woocommerce
 * @subpackage Product_Brands_For_Woocommerce/public
 */
class Product_Brands_For_Woocommerce_Public {


	/**
	 * The ID of this plugin.
	 *
	 * @since  1.0.0
	 * @var    string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since  1.0.0
	 * @var    string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 1.0.0
	 * @param string $plugin_name The name of the plugin.
	 * @param string $version     The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since 1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Product_Brands_For_Woocommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Product_Brands_For_Woocommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/product-brands-for-woocommerce-public.css', array(), $this->version, 'all');
		wp_enqueue_style( 'dashicons' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since 1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Product_Brands_For_Woocommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Product_Brands_For_Woocommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/product-brands-for-woocommerce-public.js', array( 'jquery' ), $this->version, false);
		wp_enqueue_script($this->plugin_name . '_slick', plugin_dir_url(__FILE__) . 'js/slick.min.js', array( 'jquery' ), $this->version, false);

	}


	public function product_brands_for_woocommerce_add_brand_info() {
		$disable_brand_on_product_page = get_option( 'product_brands_for_woocommerce_disable_brand_on_product_page', 'no' );
		if ( 'no' == $disable_brand_on_product_page ) {
			$brand_info = product_brands_for_woocommerce_get_brand_information();
			echo wp_kses_post( $brand_info );
		}
	}


	public function product_brands_for_woocommerce_add_noindex_nofollow() {
		if ( is_tax('product-brand') ) {
			$metas = array();
			if ( 'no' !== get_option( 'product_brands_for_woocommerce_noindex_brand_archive_pages', 'no' ) ) {
				$metas[] = 'noindex';
			}
			if ( 'no' !== get_option( 'product_brands_for_woocommerce_nofollow_brand_archive_pages', 'no' ) ) {
				$metas[] = 'nofollow';
			}
			if ( count($metas) > 0 ) {
				$meta_attrib = implode(',', $metas);
				echo '<meta name="robots" content="' . esc_attr($meta_attrib) . '" />';
			}
		}
	}
	

}
